"""Sirchmunk WebUI source (Next.js).

This file is a packaging marker that allows the web/ directory to be
included in the installed Python package as ``sirchmunk._web``.  It is
not used at runtime by the Next.js application.
"""
